Scripts
=======

This directory contains command-line scripts for the affiliated package.

We have a naming convention: all tool names should start with `gammapy-`
and all words should be separated by hyphens, e.g. `gammapy-info`.
